import socket
import threading
import logging

logger = logging.getLogger("VIEWER").getChild(__name__)


def socket_server_thread(shared_memory, active_time_memory, host='localhost', port=65432):
    server_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    server_socket.bind((host, port))
    server_socket.listen()

    while shared_memory.value:  # 共有メモリの値がTrueの間、ループを続ける
        client_socket, addr = server_socket.accept()

        with client_socket:
            while True:
                data = client_socket.recv(1024)
                if not data:
                    break
                message = data.decode('utf-8')
                if message.lower() == "pause":
                    active_time_memory.value = False
                elif message.lower() == "resume":
                    active_time_memory.value = True
                elif message.lower() == "stop":
                    active_time_memory.value = False
                    shared_memory.value = False
                else:
                    pass
    logger.info("Server thread is stopping.")


def start_server(shared_memory, active_time_memory):
    server_thread = threading.Thread(target=socket_server_thread, args=(shared_memory, active_time_memory))
    server_thread.daemon = True  # Allow the thread to exit when the main thread does
    server_thread.start()

